@@ -37,9 +37,9 @@ QVariant Item::read(uint, const QVariant &value) const
 
 void Item::setPrettyFormat(Format format)
 {
-    bool buint = ( _default.type()==QVariant::UInt );
-    bool bdouble = ( _default.type()==QVariant::Double );
-    bool bnum = ( buint || bdouble || _default.type()==QVariant::Int );
+    bool buint = (_default.metaType().id() == QMetaType::UInt);
+    bool bdouble = (_default.metaType().id() == QMetaType::Double);
+    bool bnum = (buint || bdouble || _default.metaType().id() == QMetaType::Int);
 
     switch (format) {
     case OneDecimal:
@@ -50,7 +50,7 @@ void Item::setPrettyFormat(Format format)
         Q_ASSERT(bnum);
         break;
     case DateTime:
-    	Q_ASSERT( _default.type()==QVariant::DateTime );
+        Q_ASSERT(_default.metaType().id() == QMetaType::QDateTime);
 	break;
     case NoFormat:
         break;
@@ -61,9 +61,9 @@ void Item::setPrettyFormat(Format format)
 
 void Item::setPrettySpecial(Special special)
 {
-    bool buint = ( _default.type()==QVariant::UInt );
-    bool bnum = ( buint || _default.type()==QVariant::Double
-                  || _default.type()==QVariant::Int );
+    bool buint = (_default.metaType().id() == QMetaType::UInt);
+    bool bnum = (buint || _default.metaType().id() == QMetaType::Double
+                 || _default.metaType().id() == QMetaType::Int);
 
     switch (special) {
     case ZeroNotDefined:
@@ -75,7 +75,7 @@ void Item::setPrettySpecial(Special special)
     case DefaultNotDefined:
         break;
     case Anonymous:
-        Q_ASSERT( _default.type()==QVariant::String );
+        Q_ASSERT(_default.metaType().id() == QMetaType::QString);
         break;
     case NoSpecial:
         break;
@@ -150,7 +150,7 @@ QVariant Score::data(const QString &name) const
 void Score::setData(const QString &name, const QVariant &value)
 {
     Q_ASSERT( _data.contains(name) );
-    Q_ASSERT( _data[name].type()==value.type() );
+    Q_ASSERT(_data[name].metaType() == value.metaType());
     _data[name] = value;
 }
 
@@ -245,11 +245,11 @@ void MultiplayerScores::show(QWidget *parent)
     }
 
     // order the players according to the number of won games
-    QVector<Score> ordered;
+    QList<Score> ordered;
     for (int i=0; i<_scores.size(); i++) {
         uint won = _scores[i].data(QStringLiteral( "nb won games" )).toUInt();
         double mean = _scores[i].data(QStringLiteral( "mean score" )).toDouble();
-        QVector<Score>::iterator it;
+        QList<Score>::iterator it;
         for(it = ordered.begin(); it!=ordered.end(); ++it) {
             uint cwon = (*it).data(QStringLiteral( "nb won games" )).toUInt();
             double cmean = (*it).data(QStringLiteral( "mean score" )).toDouble();
